@@ -178,7 +178,7 @@ pub use util::*;
 #[cfg_attr(doc_cfg, doc(cfg(feature = "validation")))]
 pub use validation::{
     check_archived_root_with_context, check_archived_value_with_context,
-    validators::{check_archived_root, check_archived_value},
+    validators::{check_archived_root, check_archived_value, from_bytes},
 };
 
 /// A type that can produce an error.
@@ -238,13 +238,15 @@ impl Default for Infallible {
 /// generated. See the [`Archive`](macro@Archive) derive macro for more details.
 ///
 /// ```
-/// use rkyv::{
-///     archived_root,
-///     ser::{Serializer, serializers::AllocSerializer},
-///     AlignedVec, Archive, Deserialize, Infallible, Serialize,
-/// };
+/// use rkyv::{Archive, Deserialize, Serialize};
+/// // bytecheck can be used to validate your data if you want
+/// use bytecheck::CheckBytes;
 ///
-/// #[derive(Archive, Serialize, Deserialize, Debug, PartialEq)]
+/// #[derive(Archive, Deserialize, Serialize, Debug, PartialEq)]
+/// // This will generate a PartialEq impl between our unarchived and archived types
+/// #[archive(compare(PartialEq))]
+/// // To use the safe API, you have to derive CheckBytes for the archived type
+/// #[archive_attr(derive(CheckBytes, Debug))]
 /// struct Test {
 ///     int: u8,
 ///     string: String,
@@ -257,17 +259,28 @@ impl Default for Infallible {
 ///     option: Some(vec![1, 2, 3, 4]),
 /// };
 ///
-/// let mut serializer = AllocSerializer::<4096>::default();
+/// // Serializing is as easy as a single function call
+/// let bytes = rkyv::to_bytes::<_, 256>(&value).unwrap();
+///
+/// // Or you can customize your serialization for better performance
+/// // and compatibility with #![no_std] environments
+/// use rkyv::ser::{Serializer, serializers::AllocSerializer};
+///
+/// let mut serializer = AllocSerializer::<0>::default();
 /// serializer.serialize_value(&value).unwrap();
-/// let buf = serializer.into_serializer().into_inner();
+/// let bytes = serializer.into_serializer().into_inner();
 ///
-/// let archived = unsafe { archived_root::<Test>(buf.as_slice()) };
-/// assert_eq!(archived.int, value.int);
-/// assert_eq!(archived.string, value.string);
-/// assert_eq!(archived.option, value.option);
+/// // You can use the safe API for fast zero-copy deserialization
+/// let archived = rkyv::check_archived_root::<Test>(&bytes[..]).unwrap();
+/// assert_eq!(archived, &value);
 ///
-/// let deserialized = archived.deserialize(&mut Infallible).unwrap();
-/// assert_eq!(value, deserialized);
+/// // Or you can use the unsafe API for maximum performance
+/// let archived = unsafe { rkyv::archived_root::<Test>(&bytes[..]) };
+/// assert_eq!(archived, &value);
+///
+/// // And you can always deserialize back to the original type
+/// let deserialized: Test = archived.deserialize(&mut rkyv::Infallible).unwrap();
+/// assert_eq!(deserialized, value);
 /// ```
 ///
 /// Many of the core and standard library types already have `Archive` implementations available,
